summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoChild.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kofficecore/KoChild.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficecore/KoChild.h')
-rw-r--r--lib/kofficecore/KoChild.h77
1 files changed, 39 insertions, 38 deletions
diff --git a/lib/kofficecore/KoChild.h b/lib/kofficecore/KoChild.h
index 26ad4a08..64f41064 100644
--- a/lib/kofficecore/KoChild.h
+++ b/lib/kofficecore/KoChild.h
@@ -19,18 +19,18 @@
#ifndef __koChild_h__
#define __koChild_h__
-#include <qobject.h>
-#include <qwmatrix.h>
+#include <tqobject.h>
+#include <tqwmatrix.h>
#include <koffice_export.h>
/**
* KoChild is an abstract base class that represents the geometry
* associated with an embedded document. In general it handles its position
* relative to the embedded document's parent.
*
* In detail it handles size, matrix operations and can give you
* a clip region. It can deal with scaling, rotation etc. because it
* makes heavy usage of QWMatrix.
*
* After applying the matrix, viewGeometry() applies zooming, but can be
* reimplemented to also apply e.g. some translation by the application
@@ -38,9 +38,10 @@
*
* @see KoDocumentChild KoViewChild
*/
-class KOFFICECORE_EXPORT KoChild : public QObject
+class KOFFICECORE_EXPORT KoChild : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -55,54 +56,54 @@ public:
enum Gadget { NoGadget, TopLeft, TopMid, TopRight, MidLeft, MidRight,
BottomLeft, BottomMid, BottomRight, Move };
- KoChild( QObject *parent = 0, const char *name = 0 );
+ KoChild( TQObject *tqparent = 0, const char *name = 0 );
virtual ~KoChild();
/**
* Sets a new geometry for this child document.
* Use noEmit = true if you do not want the 'changed'-signal to be emitted
*/
- void setGeometry( const QRect &rect, bool noEmit = false );
+ void setGeometry( const TQRect &rect, bool noEmit = false );
/**
* @return the rectangle that would be used to display this
* child document if the child is not rotated or
* subject to some other geometric transformation.
* The rectangle is in the coordinate system of the parent,
* using unzoomed coordinates in points.
*
* @see #setGeometry
*/
- QRect geometry() const;
+ TQRect tqgeometry() const;
/**
* @return the region of this child part relative to the
* coordinate system of the parent.
* The region is transformed with the passed
* matrix.
*/
- virtual QRegion region( const QWMatrix& = QWMatrix() ) const;
+ virtual TQRegion region( const TQWMatrix& = TQWMatrix() ) const;
/**
* @return the polygon which surrounds the child part. The points
* are in coordinates of the parent.
* The points are transformed with the
* passed matrix.
*/
- virtual QPointArray pointArray( const QWMatrix &matrix = QWMatrix() ) const;
+ virtual TQPointArray pointArray( const TQWMatrix &matrix = TQWMatrix() ) const;
/**
* Tests whether the part contains a certain point. The point is
* in the coordinate system of the parent.
*/
- //virtual bool contains( const QPoint& ) const;
+ //virtual bool tqcontains( const TQPoint& ) const;
/**
* @return the effective bounding rect after all transformations.
* The coordinates of the rectangle are in the coordinate system
- * of the parent.
+ * of the tqparent.
*/
- QRect boundingRect() const;
+ TQRect boundingRect() const;
/**
* Scales the content of the child part. However, that does not
@@ -148,16 +149,16 @@ public:
/**
* Sets the center of the rotation to the point @p pos.
*/
- virtual void setRotationPoint( const QPoint& pos );
+ virtual void setRotationPoint( const TQPoint& pos );
/**
* @return the center of the rotation
*/
- virtual QPoint rotationPoint() const;
+ virtual TQPoint rotationPoint() const;
/**
* @return true if the child part is an orthogonal rectangle relative
- * to its parents coordinate system.
+ * to its tqparents coordinate system.
*/
bool isRectangle() const;
@@ -170,14 +171,14 @@ public:
* of the current region with the childs region or whether only
* the childs region is set.
*/
- virtual void setClipRegion( QPainter& painter, bool combine = true );
+ virtual void setClipRegion( TQPainter& painter, bool combine = true );
/**
* Transforms the painter (its worldmatrix and the clipping)
* in such a way that the painter can be passed to the child part
* for drawing.
*/
- virtual void transform( QPainter& painter );
+ virtual void transform( TQPainter& painter );
/**
* Sets the position of the content relative to the child frame.
@@ -188,25 +189,25 @@ public:
/**
* @return the contents rectangle that is visible.
* This value depends on the scaling and the geometry.
* This is the value that is passed to KoDocument::paintContent.
*
- * @see #xScaling #geometry
+ * @see #xScaling #tqgeometry
*/
- virtual QRect contentRect() const;
+ virtual TQRect contentRect() const;
/**
* @return the region of the child frame.
* If solid is set to true the complete area of the child region
* is returned, otherwise only the child border is returned.
*/
- virtual QRegion frameRegion( const QWMatrix& matrix = QWMatrix(), bool solid = false ) const;
+ virtual TQRegion frameRegion( const TQWMatrix& matrix = TQWMatrix(), bool solid = false ) const;
/**
* @return the frame geometry including a border (6 pixels) as a point
* array with 4 points, one for each corner, transformed by given matrix.
*/
- virtual QPointArray framePointArray( const QWMatrix &matrix = QWMatrix() ) const;
+ virtual TQPointArray framePointArray( const TQWMatrix &matrix = TQWMatrix() ) const;
/**
* @return the current transformation of this child as matrix.
@@ -214,7 +215,7 @@ public:
*
* @see #updateMatrix
*/
- virtual QWMatrix matrix() const;
+ virtual TQWMatrix matrix() const;
/**
* Locks this child and stores the current transformation.
@@ -233,11 +234,11 @@ public:
void unlock();
/**
* If the child is locked, geometry changes
* (including scaling, rotation, ...) are not backed up.
*
* As long as this child is locked, the backed up
* geometry state can be recovered with oldPointArray.
*
* @return true when this child is locked.
*
@@ -246,9 +247,9 @@ public:
bool locked() const;
/**
* @return the backed up geometry transformed by given matrix.
*/
- virtual QPointArray oldPointArray( const QWMatrix &matrix );
+ virtual TQPointArray oldPointArray( const TQWMatrix &matrix );
/**
* Marks this child as either transparent or not.
@@ -260,7 +261,7 @@ public:
virtual void setTransparent( bool transparent );
/**
- * It might be interesting for view updates and repainting in general
+ * It might be interesting for view updates and tqrepainting in general
* whether a child is transparent or not.
* @return true when this child is marked as transparent.
*/
@@ -275,7 +276,7 @@ public:
*
* @see #Gadget
*/
- virtual Gadget gadgetHitTest( const QPoint& p );
+ virtual Gadget gadgetHitTest( const TQPoint& p );
signals:
@@ -295,7 +296,7 @@ protected:
* @param matrix the transformation of r.
* @param r the rectangle for which the point array should be created.
*/
- virtual QPointArray pointArray( const QRect& r, const QWMatrix& matrix = QWMatrix() ) const;
+ virtual TQPointArray pointArray( const TQRect& r, const TQWMatrix& matrix = TQWMatrix() ) const;
/**
* Stores the current transformation of this child into a matrix.
@@ -19,18 +19,18 @@
#include <koffice_export.h>
/**
- * KoChild is an abstract base class that represents the geometry
+ * KoChild is an abstract base class that represents the tqgeometry
* associated with an embedded document. In general it handles its position
@@ -19,18 +19,18 @@
* associated with an embedded document. In general it handles its position
- * relative to the embedded document's parent.
+ * relative to the embedded document's tqparent.
*
* In detail it handles size, matrix operations and can give you
@@ -19,18 +19,18 @@
* In detail it handles size, matrix operations and can give you
* a clip region. It can deal with scaling, rotation etc. because it
- * makes heavy usage of QWMatrix.
+ * makes heavy usage of TQWMatrix.
*
* After applying the matrix, viewGeometry() applies zooming, but can be
@@ -55,54 +56,54 @@ public:
virtual ~KoChild();
/**
- * Sets a new geometry for this child document.
+ * Sets a new tqgeometry for this child document.
* Use noEmit = true if you do not want the 'changed'-signal to be emitted
*/
@@ -55,54 +56,54 @@ public:
* child document if the child is not rotated or
* subject to some other geometric transformation.
- * The rectangle is in the coordinate system of the parent,
+ * The rectangle is in the coordinate system of the tqparent,
* using unzoomed coordinates in points.
*
@@ -55,54 +56,54 @@ public:
/**
* @return the region of this child part relative to the
- * coordinate system of the parent.
+ * coordinate system of the tqparent.
* The region is transformed with the passed
* matrix.
@@ -55,54 +56,54 @@ public:
/**
* @return the polygon which surrounds the child part. The points
- * are in coordinates of the parent.
+ * are in coordinates of the tqparent.
* The points are transformed with the
* passed matrix.
@@ -55,54 +56,54 @@ public:
/**
* Tests whether the part contains a certain point. The point is
- * in the coordinate system of the parent.
+ * in the coordinate system of the tqparent.
*/
@@ -188,25 +189,25 @@ public:
/**
* @return the contents rectangle that is visible.
- * This value depends on the scaling and the geometry.
+ * This value depends on the scaling and the tqgeometry.
* This is the value that is passed to KoDocument::paintContent.
*
@@ -188,25 +189,25 @@ public:
/**
- * @return the frame geometry including a border (6 pixels) as a point
+ * @return the frame tqgeometry including a border (6 pixels) as a point
* array with 4 points, one for each corner, transformed by given matrix.
*/
@@ -233,11 +234,11 @@ public:
void unlock();
/**
- * If the child is locked, geometry changes
+ * If the child is locked, tqgeometry changes
* (including scaling, rotation, ...) are not backed up.
*
@@ -233,11 +234,11 @@ public:
*
* As long as this child is locked, the backed up
- * geometry state can be recovered with oldPointArray.
+ * tqgeometry state can be recovered with oldPointArray.
*
* @return true when this child is locked.
@@ -246,9 +247,9 @@ public:
bool locked() const;
/**
- * @return the backed up geometry transformed by given matrix.
+ * @return the backed up tqgeometry transformed by given matrix.
*/